#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright 2008-2009 Zuza Software Foundation
#
# This file is part of the Translate Toolkit.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, see <http://www.gnu.org/licenses/>.

"""The Translate Toolkit is a Python package that assists in localization of software.

See U{http://translate.sourceforge.net/wiki/toolkit/index} or U{http://translate.org.za} for more information.

@organization: Zuza Software Foundation
@copyright: 2002-2009 Zuza Software Foundation
@license: U{GPL <http://www.fsf.org/licensing/licenses/gpl.html>}

@group Localization and Localizable File Formats: storage
@group Format Converters: convert
@group Localisation File Checker: filters
@group Localization File Manipulation Tools: tools
@group Language Specifications: lang
@group Search and String Matching: search
@group Services: services
@group Miscellaneous: misc source_tree_infrastructure __version__

"""
